# POÈME POUR YASMINE

[pdf](./src/yasmine/texte/texte.pdf) – [html](./src/yasmine/texte/texte.html) – [txt](./src/yasmine/texte/texte.txt)

```
$ pip install yasmine
$ python -m yasmine
```

```
POÈME POUR YASMINE

Si facile d’aimer, si dur de n’aimer plus :
Qui vient vider la chambre où le cœur est reclus
Des parfums enchâssés, des goûts, des sens, des traces,
Des souvenirs présents et des objets vivaces ?

Nul ne peut effacer, après avoir marqué
Au fer rouge, un mot dit et plus tard révoqué :
Nulle force, nul dieu, tant le passé m’habite,
Ne peut faire sortir mon cœur de son orbite.

Je suis un homme entier, au cœur tendre et châtié ;
Je ne sais ni mentir, ni aimer à moitié :
Quand j’aime je ne sais comment tourner la page,
Ni, quand il faut partir, comment plier bagage.

Je vois devant mes yeux un film se défiler ;
Spectateur impuissant, je vois tout s’effiler :
Je vois mon désarroi nargué par la vitesse
Du temps qui passe, court, file et tout seul me laisse.

Que ce monde est changeant, qu’il est impermanent ;
Que le calme trahit et que le sermon ment.
Il change qu’il surprend : il donne et prend, redonne
Et reprend, il t’adopte et enfin t’abandonne.

Il arrache et fait don, reprend après donner,
Donne à sa guise et prend en faisant ordonner
Que toujours ses sujets s’enferment dans son coffre
Et restent satisfaits de ce peu qu’il leur offre.

Mon âme n’est pas faite à céder aux violents 
Qui veulent, comme ça, ces fous, ces insolents,
Sans avertissement, sans avis, sans prélude,
La faire renoncer à sa vieille habitude.

Comment peut-on laisser un cœur clair s’imprégner
D’amour jusqu’à la moelle et ensuite espérer
Qu’il sache par lui même obéir sur demande
Et qu’il change au signal d’une télécommande ?

Perte totale – oh Dieu – j’ai perdu, tout perdu !
Parti l’objet perdu dont j’étais éperdu :
Mon esprit est désert et mon âme est déserte,
Seuls mes yeux sont restés pour regretter ma perte.

Je n’aurai plus besoin – à mon plus grand regret –
Ni de comploter pour nous voir dans le secret,
Ni, pour te retrouver, de traverser la terre,
Ni de feindre la foi pour séduire ta mère.

Tu ne pourras plus, belle, enlacer mon chemin,
Ni découvrir Paris en me tenant la main.
Moi, je ne pourrai plus t’embrasser ma très chère
Et je ne viendrai pas te voir en Angleterre.

Mon vingt-mètres parisien ne connaîtra pas
L’odeur de ta présence et le bruit de tes pas.
Pont Neuf ne sera pas témoin de notre idylle
Et l’eau sous Mirabeau ne sera plus utile.

La Seine sous l’Alma coule avec vanité :
Face à moi le néant de la banalité
À regarder sans toi, j’en deviens une épave,
Le fleuve parisien noyer les pieds du Zouave.

Tous les ponts de Paris croulent devant mes yeux
Ils croulent et je croule, et je coule avec eux.
L’homme est frêle et fragile : une feuille d’érable
Sur la Seine – et la mer pour dernier réceptacle.

Au centre Pompidou, nous n’irons pas demain
Pour rire et nous moquer de l’art contemporain.
Il y a là un objet : sorte de vieux potage
Qu’on court vite oublier au tout dernier étage.

Images et tableaux, plein de créations ;
Cent mille arts et autant d’hallucinations :
Repense à ce chef-d'œuvre aux écouteurs filaires
Pêle-mêle emmêlés sur fond de sons stellaires.

Souviens-toi, tu voulais venir et rajouter
Tes écouteurs à toi, pour bien la compléter.
Même sans moi, fais, fais : elle en sera sauvée
Quand tu compléteras cette œuvre inachevée.

Boulevard Saint-Michel jusqu’au Lion de Belfort,
Nous ne marcherons pas voir le lion qui ne dort
Jamais : objet altier entre les créatures
Mais morose et maussade à voir trop de voitures.

Nous n’irons pas, ma chère, à Denfert-Rochereau :
Vide sera Denfert, seul est le tourtereau.
Nous n’irons ni nourrir au square les colombes,
Ni approcher la Mort au fond des Catacombes.

Les crânes parisiens resteront seuls, sans nous :
Ces admirables os posés sur des cailloux,
Agrémentés de vers – parfois réduits en miettes ;
Qui me regardera regarder ces squelettes ?

La fontaine Carpeaux ne sait rendre vivant ;
La Mort fauche et prend tout, prend et passe au suivant.
Le joli monument nous montre notre monde :
Prison sur pieds boiteux que l’injustice inonde.

Les fleurs du Luxembourg devront, sans nous, fleurir
Alors que notre absence astreint tout à mourir ;
La prochaine saison, le jardin sera fade
Et, à ne pas nous voir, demeurera malade.

Le monde est dépeuplé, fantôme est Vaugirard ;
La nuit sombre en plein jour prolonge le brouillard ;
La noirceur voile tout dans mon âme confuse,
Et dans mon cœur contrit où l’obscurité fuse.

Le pavé de Férou nous attendra longtemps :
Les volets sont amers, les balcons mécontents
De ne pas voir venir nos deux êtres qui s’aiment,
Ensemble joints, s’asseoir et lire le poème.

Nous ne serons pas, chère, adossés, face au mur,
Transis devant la fresque où le texte d’Arthur
Rimbaud dit et dit tout, se révèle et se livre ;
L’Amérique c’est toi : je suis le Bateau Ivre.

Nous n’irons pas, ma chère, admirer le voilier 
De la maison Vuitton ; voir le flot régulier
Venir jusqu’à nos pieds, sans nous toucher nous faire
Flotter sur le bassin jusqu’à nous satisfaire.

Moqueurs, nous n’irons pas dans ces lieux fourmillants
De gens, moquer, choquer un à un les croyants ;
Et ne sera jamais par nos mots offusquée
L’église Saint-Sulpice ou la Grande Mosquée.

Rappelle-toi du film et entends mon soupir,
Midnight in Paris, chère, en as-tu souvenir ?
Nous nous sommes promis de faire cette ville
À deux, mais aujourd’hui mon espoir est fragile.

Nous ne pourrons jamais ma petite souris
Dresser le palmarès des croissants de Paris.
Et ce Paris-Brest va rester dans sa vitrine,
Quel intérêt peut-il avoir sans toi Yasmine ?

Le métro parisien et le métro d’Alger
N’auront pas le bonheur de nous voir voyager :
Il devra démarrer, le train, sans nous attendre,
Et lors de ses arrêts, nous ne pourrons descendre.

Il démarre toujours et, sans aucun retard,
La cruelle Nature annonce son départ ;
Le train des jours s’en va sans doute ou réticence
Et laisse à ces humains le froid de son absence.

Il m’aveugle les yeux de sa coruscation
Et me laisse esseulé au quai de la station :
Il trace son chemin d’une vitesse fière
Et fait derrière lui un halo de lumière.

Rappelle-toi, mon cœur, notre premier baiser,
Aux Beaux-Arts, à Alger, où l’art sait apaiser
Un gardien pour fermer l’œil sur notre indécence
Et nous laisser aimer à notre convenance.

Nous nous sommes aimés, nous nous sommes fâchés
Quelques fois ; mais toujours nous étions attachés
L’un à l’autre et à nous : nos deux cœurs toujours trouvent
Le moyen pour s’aimer et pour qu’ils se retrouvent.

Après un petit froid de grêle et de grêlons
Le beau soleil revient et darde ses rayons :
Ma chère, n’est-ce pas le gris de nos grisailles
Qui rend sublime et fait le goût des retrouvailles ?

Chère, comme étions-nous si proche dans ce train
Quand nous serrions nos mains avec force et entrain :
Nous nous y sentions seuls – pourtant bondé de monde,
Le train se mouvait sans troubler l’union profonde.

L’un à l’autre collés, nous blaguions à loisir
Entre deux longs regards pénétrés de désir :
Nous voulions que le temps allège son allure,
Que le train tombe en panne et que ce moment dure.

Ma main dans tes cheveux venait sans prévenir
Frôler ta chevelure avant de revenir
Dans le creux de ta paume (avec ma main oisive)
Écraser le chewing-gum baignant dans ta salive.

Nous étions tous les deux contre l’adversité
En symbiose et unis devant l’éternité :
Une chanson disait en boucle dans nos têtes
Notre amour – et le reste était aux oubliettes.

Cette musique en boucle ondulait dans nos cœurs ,
Resserrait notre lien et repoussait nos peurs.
Frissons sur tout le corps, papillons dans le ventre ;
Le monde était à nous : nous en étions le centre.

Un banc à Boumerdès, dans un petit jardin,
Un jour qui aurait pu être un jour anodin
Si ce n’était nous deux qui étions de passage
Et qui avons manqué d’être un couple bien sage.

Rappelle-toi, mon cœur, notre complicité ;
Nous aimions notre union dans sa simplicité :
Comment peut-on après avoir été si proches
Devenir étrangers aux cœurs remplis de roches ?

J’aimais – te souviens-tu ? – te donner à manger,
Te nourrir de ma main, et pour t’encourager,
Te dire que c’est bien, petit bébé, mon ange,
Je n’ai de goût que quand c’est Yasmine qui mange.

J’adorais, souviens-toi, venir après manger,
Porter jusqu’à ta bouche une eau pour soulager
Ta soif et l’étancher : que j’aime voir descendre
L’eau à travers ta gorge et un peu se répandre.

J’aime te voir manger et t’entendre croquer ;
J’aime ton rototo et j’aime ton hoquet ;
J’aime te voir mâcher et t’entendre le faire ;
Et quand t'en mets partout, c’est ce que je préfère.

J’aime presser ta lèvre et ta bouche carmin
Pour l’essuyer après boire et avec ma main
Effacer chaque tache et chaque salissure,
La miette sur ta joue et sur ta commissure.

Pour t’oublier, je fais l’effort de me mentir,
De m’occuper à tout et de me divertir :
Je regarde Squid Game et je vois cette actrice,
Ton visage à nouveau dans ma tête se hisse.

Mon ange, mon amour, mon opium adoré,
Mon koala, mon cœur, mon sucre coloré,
Ma mignonne, mon tout, ma douce, ma berbère,
Mon minouche, mon chou, ma Bougiote, ma chère.

Tu m’as laissé t’aimer sans jamais prévenir
Que tu pouvais un jour brutalement partir :
Tu m’as ouvert les bras, tu m’as ouvert la porte ;
Tu ne peux, aujourd’hui, la fermer de la sorte.

Je ne sais désaimer ce que j’aime une fois
Et ne sais me soumettre, entre toutes les lois,
Qu’à celle de mon cœur qui sait tout et ignore
Cesser ce qu’il commence : il aime et aime encore.


Villejuif, 7 novembre 2021
```
